##### Search Statistics

NDR Core can collect anonymous search statistics. You can turn on the feature and each time a user performs a search, the search term, time and date, general location (i.e. country of internet provider), and used search form are logged. You can view the logs in the administration interface, reset them and export them for further analysis.

NDR Core does not log any user data when logging search statistics. No IP's or other information apart from the search terms and general location (based on GeoIP2) are logged.